<?php
class translate {

    /**
     * Last language loaded
     * @access private
     * @var    string
     */
	var $_sLocale = "en-US";
	
	var $domains = array();

	/**
	* @var boolean
	*/

	var $show_errormessages = false;

	/**
	* @param string $domains
	* @param string $TranslationsPath
	* @return void
	*/
	function translate($domain = 'main', $TranslationsPath = NULL ) {
		global $Config_root_dir,$Config_locale;
		if( $this->isValidLocaleCode($Config_locale) )
			$this->_sLocale = $Config_locale;
		$this->_sTranslationsPath = is_null($TranslationsPath) ? $Config_root_dir.'/locale' : $TranslationsPath;
		$this->setDomains($domain);
	} // end constructor
	
	function setDomains($domain) {
		$language_file = $this->_sTranslationsPath . DIRECTORY_SEPARATOR . $this->_sLocale . DIRECTORY_SEPARATOR . 'LC_MESSAGES' . DIRECTORY_SEPARATOR . $domain . '.php';
		if( file_exists($language_file) ){
			if(! isset($this->domains[$domain]) ){
				include_once($language_file);
			}
		}else {
			if ($this->show_errormessages)
				echo '<br />'.$domain.' not exist!<br />';
		}
	} // end function

	/**
	 * Retrieves the translation of $translationstring. If the gettext isn't loaded the original text is returned.
	 * @param string $translationstring Text to translate.
	 * @param string $domain Domain to retrieve the translated text.
	 * @return string Translated text or error message
	 */
	function gettext($translationstring) {
		foreach($this->domains as &$domain){
			if(isset($domain[$translationstring]))
				return $domain[$translationstring];
		}
		if ($this->show_errormessages) {
			trigger_error('TRANSLATION ERROR: String "' . $translationstring . '" not found!', E_USER_WARNING);
		} // end if
		return $translationstring;
	} // end function

	/**
	* shortcut wrapper method for the translate() method
	*/
	function _($translationstring) {
		return $this->gettext($translationstring);
	} // end function
	
	/**
	 * Displays the returned translated text from translate().
	 *
	 * @see translate() Echoes returned translate() string
	 * @param string $translationstring Text to translate
	 * @param string $domain Optional. Domain to retrieve the translated text
	 */
	function _e( $translationstring ) {
		echo $this->gettext( $translationstring );
	}

	/**
	 * Retrieves the translation of $translationstring and escapes it for safe use in HTML.
	 * If there is no translation, or the domain isn't loaded the original text is returned.
	 * Converts a number of special characters into their HTML entities.
	 *
	 * Specifically deals with: &, <, >, ", and '.
	 *
	 * $quote_style can be set to ENT_COMPAT to encode " to &quot;
	 * , or ENT_QUOTES to do both. Default is ENT_NOQUOTES where no quotes are encoded.
	 *
	 * @param string $translationstring Text to translate
	 * @param string $domain Optional. Domain to retrieve the translated text
	 * @param mixed $quote_style Optional. Converts double quotes if set to ENT_COMPAT, both single and double if set to ENT_QUOTES or none if set to ENT_NOQUOTES.
	 * @param string $charset Optional. The character encoding of the string. Default is UTF-8.
	 * @return string Translated text
	 */
	function esc( $translationstring, $domain = null, $quote_style = ENT_QUOTES, $charset = 'UTF-8' ) {
		return htmlspecialchars( $this->gettext($translationstring), $quote_style, $charset );
	}
	
	function esc_e( $translationstring, $domain = null ) {
		echo $this->esc( $translationstring );
	}

	/**
	* checks if a given locale is valid
	* @param string $code de, de-AT,...
	* @return boolean
	*/
	function isValidLocaleCode($code = '') {
		return preg_match('(^([a-zA-Z]{2})((_|-)[a-zA-Z]{2})?$)', $code);
	} // end function

} // end class translate
?>